@@ -1300,6 +1300,16 @@ class S(PythonMixin):
                     lower, upper = val
                     rv.append({'range': {key: {'gte': lower, 'lte': upper}}})
 
+                elif field_action == 'distance':
+                    distance, latitude, longitude = val
+
+                    rv.append({
+                        'geo_distance': {
+                            'distance': distance,
+                            key: [longitude, latitude]
+                        }
+                    })
+
                 else:
                     raise InvalidFieldActionError(
                         '%s is not a valid field action' % field_action)
@@ -2060,6 +2070,11 @@ class MappingType(object):
             # subclasses.
             return self.get_object()
 
+        if name == '_results_dict':
+            # Prevent infinite recursion when unpickling a
+            # mapping type instance.
+            raise AttributeError(name)
+
         # If that doesn't exist, then check the results_dict.
         if name in self._results_dict:
             return self._results_dict[name]
