@@ -1,4 +1,5 @@
 from datetime import date, datetime
+import pickle
 
 from nose.tools import eq_
 
@@ -174,9 +175,11 @@ class TestResultsWithStoredFields(ESTestCase):
         self.create_index(
             mappings={
                 self.mapping_type_name: {
-                    'id': {'type': 'integer'},
-                    'name': {'type': 'string'},
-                    'weight': {'type': 'integer'},
+                    'properties': {
+                        'id': {'type': 'integer'},
+                        'name': {'type': 'string'},
+                        'weight': {'type': 'integer'},
+                    }
                 }
             }
         )
@@ -227,9 +230,11 @@ class TestResultsWithStoredFields(ESTestCase):
         self.create_index(
             mappings={
                 self.mapping_type_name: {
-                    'id': {'type': 'integer'},
-                    'name': {'type': 'string'},
-                    'weight': {'type': 'integer'},
+                    'properties': {
+                        'id': {'type': 'integer'},
+                        'name': {'type': 'string'},
+                        'weight': {'type': 'integer'},
+                    }
                 }
             }
         )
@@ -308,9 +313,11 @@ class TestResultsWithDates(ESTestCase):
         self.create_index(
             mappings={
                 self.mapping_type_name: {
-                    'id': {'type': 'integer'},
-                    'bday': {'type': 'date', 'format': 'YYYY-mm-dd'},
-                    'btime': {'type': 'date'}
+                    'properties': {
+                        'id': {'type': 'integer'},
+                        'bday': {'type': 'date', 'format': 'YYYY-mm-dd'},
+                        'btime': {'type': 'date'}
+                    }
                 }
             }
         )
@@ -335,8 +342,10 @@ class TestResultsWithDates(ESTestCase):
         self.create_index(
             mappings={
                 self.mapping_type_name: {
-                    'id': {'type': 'integer'},
-                    'bday': {'type': 'string', 'analyzer': 'keyword'}
+                    'properties': {
+                        'id': {'type': 'integer'},
+                        'bday': {'type': 'string', 'analyzer': 'keyword'}
+                    }
                 }
             }
         )
@@ -403,3 +412,16 @@ class TestMappingType(ESTestCase):
         self.assertRaises(AttributeError, lambda: result.doesnt_exist)
         # If it doesn't exist, throw KeyError
         self.assertRaises(KeyError, lambda: result['doesnt_exist'])
+
+    def test_pickleable(self):
+        data = [
+            {'id': 1, '_object': 'foo'}
+        ]
+
+        self.index_data(data)
+        s = self.get_s(DefaultMappingType)
+        result = list(s)[0]
+
+        pickled_mt = pickle.dumps(result, 2)
+        unpickled = pickle.loads(pickled_mt)
+        eq_(unpickled.id, 1)
